##  Overview
The extension for application total cost of ownership empowers organizations to identify opportunities for cost savings by providing a lightweight yet trusted source for cost data. Accurate cost information is critical for informed decision-making, particularly during IT transformations and application rationalizations. With this extension, you can align architecture costs with strategic objectives through robust cost allocation and aggregation capabilities. Gain clear visibility into costs on different levels, for example based on application or business capability or organization, to drive efficiency and support your business goals.
The additions of this extension help you whenever cost data is of importance:
  * Cost management: Understand the different types of costs and how application costs relate to other cost types. Explore advanced cost management options like changing calculations.
To learn more, see [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD "Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.").
  * Application rationalization use case: Take your cost management to the next level and go through the steps of application rationalization. You’ll explore cost saving opportunities, align with the larger IT strategy, and report the success to management stakeholders.
To learn more, see [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") .
  * Advanced cost management for application total cost of ownership: Build on this extension and adjust cost data calculations to your specific needs. With the extension activated, you can add the provided calculation examples to your workspace or use them as inspiration to create a calculation for your cost definition.
To learn more, see [Advanced Cost Management with Customized Configurations](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759840a7a441014b9b08e71b843f53b__Advanced-Cost-Management-with-Customized-Configurations) .
